@@ -2,25 +2,6 @@ import pandas as pd
 import numpy as np
 import os
 
-'''check numeric for a dataframe column'''
-def Tom(df,head):
-    if not isinstance(df,pd.DataFrame): print('Tom: df should be a dataframe.'); return
-    if head not in df.columns: print('Tom: head not found in df.'); return
-    df[head]=list(map(TomCheck,df[head]))    
-
-'''check an  object for numeric'''
-def TomCheck(x):
-    extreme_value=1.0e+15
-    x=str(x)
-    if len(x)==0: return(extreme_value)
-    okset={'+','-','.','0','1','2','3','4','5','6','7','8','9'}
-    first_letter=x[0]
-    if first_letter not in okset: return(extreme_value)
-    if x.count('.')>1: return(extreme_value)
-    bad_letters=len(set(x)-okset)
-    if bad_letters>0: return(extreme_value)
-    return(float(x))
-
 '''add dumy variable'''
 def ady(df,varname,levels):
     ncov=len(levels)
